using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using BarcodeLib.Barcode;
using BarcodeLib.Barcode.DataMatrix;
using System.IO;
using System.Drawing.Imaging;
using BarcodeLib.Barcode.Linear;

namespace WinDemo
{
    public partial class DataMatrixForm : Form
    {
        public DataMatrixForm()
        {
            InitializeComponent();
        }

        private void DataMatrixForm_Load(object sender, EventArgs e)
        {
            ctrEncoding.SelectedIndex = 0;
            ctrFormat.SelectedIndex = 0;
            ctrProcessTilde.SelectedIndex = 0;
            ctrImageFormat.SelectedIndex = 0;

            ctrUOM.SelectedIndex = 0;

            dataMatrix.Data = "BarcodeLib.com";
            dataMatrix.Refresh();
        }

        private void ctrDrawBarcode_Click(object sender, EventArgs e)
        {
            bool validInputs = verifyInputs();
            if (validInputs)
                drawBarcode();
        }

        private bool verifyInputs()
        {
            string errorMessage = "";
            if (ctrData.Text.Trim().Equals(""))
            {
                errorMessage = "Barcode data cannot be empty.";
                ctrData.Focus();
            }

            try
            {
                float v = float.Parse(ctrModuleSize.Text);
                if (v <= 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for module size.";
                ctrModuleSize.Focus();
            }
            try
            {
                float v = float.Parse(ctrLeftMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for left margin.";
                ctrLeftMargin.Focus();
            }

            try
            {
                float v = float.Parse(ctrRightMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for right margin.";
                ctrRightMargin.Focus();
            }
            try
            {
                float v = float.Parse(ctrTopMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for top margin.";
                ctrTopMargin.Focus();
            }
            try
            {
                float v = float.Parse(ctrBottomMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for bottom margin.";
                ctrBottomMargin.Focus();
            }

            try
            {
                int v = int.Parse(ctrResolution.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "int only for resolution.";
                ctrResolution.Focus();
            }

            if (!errorMessage.Equals(""))
            {
                MessageBox.Show(errorMessage);
                return false;
            }

            return true;
        }

        private void drawBarcode()
        {
            dataMatrix.Data = ctrData.Text;
            dataMatrix.Encoding = BarcodeUtils.convertString2DataMatrixEncoding(ctrEncoding.Text);
            dataMatrix.Format = (DataMatrixFormat)(ctrFormat.SelectedIndex);
            dataMatrix.ProcessTilde = bool.Parse(ctrProcessTilde.Text);

            dataMatrix.UOM = (UnitOfMeasure)ctrUOM.SelectedIndex;
            dataMatrix.ModuleSize = float.Parse(ctrModuleSize.Text);
            dataMatrix.TopMargin = float.Parse(ctrTopMargin.Text);
            dataMatrix.LeftMargin = float.Parse(ctrLeftMargin.Text);
            dataMatrix.RightMargin = float.Parse(ctrRightMargin.Text);
            dataMatrix.BottomMargin = float.Parse(ctrBottomMargin.Text);

            dataMatrix.Resolution = int.Parse(ctrResolution.Text);

            dataMatrix.ImageFormat = BarcodeUtils.convertString2ImageFormat(ctrImageFormat.Text, ImageFormat.Gif); ;

            dataMatrix.Refresh();
        }

        

        private void ctrSaveImage_Click(object sender, EventArgs e)
        {
            bool validInputs = verifyInputs();
            if (!validInputs)
                return;

            saveFileDialog1.Filter = "GIF (*.gif)|*.gif|JPEG (*.jpg)|*.jpg|BMP (*.bmp)|*.bmp";
            saveFileDialog1.FilterIndex = 1;

            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                drawBarcode();

                Stream imageStream = null;
                if ((imageStream = saveFileDialog1.OpenFile()) != null)
                {
                    dataMatrix.SaveAsImage(imageStream);
                    if (imageStream != null)
                        imageStream.Close();
                }
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            base.Close();
        }

        private void dataMatrix_Load(object sender, EventArgs e)
        {

        }
    }
}